@@ -1,6 +1,3 @@
-import numpy as np
-from lstchain.calib.camera.calib import gain_selection
-from astropy.utils import deprecated
 from lstchain.calib import load_calibrator_from_config, load_gain_selector_from_config, load_image_extractor_from_config
 from ctapipe.instrument import SubarrayDescription, TelescopeDescription
 from lstchain.io.config import get_standard_config
@@ -13,27 +10,6 @@ subarray = SubarrayDescription(
     },
 )
 
-@deprecated('28/06/2019', message='gain selection is now performed at <= R1 calibration level')
-def test_gain_selection():
-    """
-    test gain selection
-    """
-    # Let's generate a fake waveform from a camera of 3 samples and 10 pixels
-    n_samples = 3
-    w1 = np.transpose([np.concatenate([np.ones(5), 3 * np.ones(5)]) for i in range(n_samples)])
-    w2 = np.transpose([10 * np.ones(10) for i in range(n_samples)])
-    waveform = np.array([w1, w2])
-    image = waveform.mean(axis=2)
-
-    threshold = 2
-    combined_image, _ = gain_selection(waveform, image, image, threshold)
-
-    # with a threshold of 2, the 5 first pixels should be selected in the first channel and 5 others in the second \
-    # channel
-
-    np.testing.assert_array_equal(combined_image, np.array([1, 1, 1, 1, 1, 10, 10, 10, 10, 10]))
-
-
 def test_load_calibrator_from_config():
     from lstchain.io.config import get_standard_config
     from ctapipe.calib import CameraCalibrator
@@ -43,17 +19,15 @@ def test_load_calibrator_from_config():
 
 
 def test_load_calibrator_from_config_LocalPeakWindowSum():
-    from ctapipe.image import LocalPeakWindowSum
     config = {"image_extractor": "LocalPeakWindowSum"}
     cal = load_calibrator_from_config(config, subarray)
-    assert isinstance(cal.image_extractor, LocalPeakWindowSum)
+    assert cal.image_extractor_type.tel[1] == 'LocalPeakWindowSum'
 
 
 def test_load_calibrator_from_config_GlobalPeakWindowSum():
-    from ctapipe.image import GlobalPeakWindowSum
     config = {"image_extractor": "GlobalPeakWindowSum"}
     cal = load_calibrator_from_config(config, subarray)
-    assert isinstance(cal.image_extractor, GlobalPeakWindowSum)
+    assert cal.image_extractor_type.tel[1] == 'GlobalPeakWindowSum'
 
 
 def test_load_image_extractor_from_config():
