@@ -7,6 +7,7 @@ from .event_selection import EventSelector, DL3FixedCuts, DataBinning
 from .io import (
     get_dataset_keys,
     auto_merge_h5files,
+    copy_h5_nodes,
     write_simtel_energy_histogram,
     write_mcheader,
     write_dl2_dataframe,
@@ -22,6 +23,7 @@ from .io import (
     HDF5_ZSTD_FILTERS,
     get_srcdep_index_keys,
     get_srcdep_params,
+    add_source_filenames,
 )
 
 standard_config = get_standard_config()
@@ -36,6 +38,7 @@ __all__ = [
     'DataBinning',
     'get_dataset_keys',
     'auto_merge_h5files',
+    'copy_h5_nodes',
     'write_simtel_energy_histogram',
     'write_mcheader',
     'write_dl2_dataframe',
@@ -51,4 +54,5 @@ __all__ = [
     'read_data_dl2_to_QTable',
     'get_srcdep_index_keys',
     'get_srcdep_params',
+    'add_source_filenames'
 ]
