@@ -5,21 +5,30 @@ import pandas as pd
 import pytest
 import tables
 from astropy.table import Table
+from ctapipe.instrument import SubarrayDescription
 
 
 @pytest.fixture
 def merged_h5file(tmp_path, simulated_dl1_file):
-    """Produce a smart merged h5 file from simulated dl1 files."""
-    from lstchain.io.io import smart_merge_h5files
+    """Produce a merged h5 file from simulated dl1 files."""
+    from lstchain.io.io import auto_merge_h5files
+
+    subarray_before = SubarrayDescription.from_hdf(simulated_dl1_file)
 
     merged_dl1_file = tmp_path / "dl1_merged.h5"
-    smart_merge_h5files(
+    auto_merge_h5files(
         [simulated_dl1_file, simulated_dl1_file], output_filename=merged_dl1_file
     )
+
+    subarray_merged = SubarrayDescription.from_hdf(merged_dl1_file)
+
+    # check that subarray name is correctly retained
+    assert subarray_before.name == subarray_merged.name
     return merged_dl1_file
 
 
 def test_write_dataframe():
+    from lstchain.io import config, global_metadata
     from lstchain.io.io import write_dataframe
 
     df = pd.DataFrame(
@@ -28,9 +37,11 @@ def test_write_dataframe():
             "N": np.random.poisson(5, size=10),
         }
     )
+    config = config.get_standard_config()
 
     with tempfile.NamedTemporaryFile() as f:
-        write_dataframe(df, f.name, "data/awesome_table")
+        meta = global_metadata()
+        write_dataframe(df, f.name, "data/awesome_table", config=config, meta=meta)
 
         with tables.open_file(f.name) as h5_file:
             # make sure nothing else in this group
@@ -41,6 +52,11 @@ def test_write_dataframe():
             for col in df.columns:
                 np.testing.assert_array_equal(table[col], df[col])
 
+            # test global metadata and config are properly written
+            for k in meta.keys():
+                assert meta[k] == h5_file.root.data.awesome_table.attrs[k]
+            assert config == h5_file.root.data.awesome_table.attrs["config"]
+
         # test it's also readable by pandas directly
         df_read = pd.read_hdf(f.name, "data/awesome_table")
         assert df.equals(df_read)
@@ -94,9 +110,13 @@ def test_merging_check(simulated_dl1_file):
 
 
 @pytest.mark.run(after="test_r0_to_dl1")
-def test_smart_merge_h5files(merged_h5file):
+def test_merge_h5files(merged_h5file):
     assert merged_h5file.is_file()
 
+    # check source filenames is properly written
+    with tables.open_file(merged_h5file) as file:
+        assert len(file.root.source_filenames.filenames) == 2
+
 
 @pytest.mark.run(after="test_r0_to_dl1")
 def test_read_simu_info_hdf5(simulated_dl1_file):
@@ -108,7 +128,7 @@ def test_read_simu_info_hdf5(simulated_dl1_file):
     assert mcheader.num_showers == 20000
 
 
-@pytest.mark.run(after="test_smart_merge_h5files")
+@pytest.mark.run(after="test_merge_h5files")
 def test_read_simu_info_merged_hdf5(merged_h5file):
     from lstchain.io.io import read_simu_info_merged_hdf5
 
@@ -131,9 +151,16 @@ def test_read_subarray_description(mc_gamma_testfile, simulated_dl1_file):
     from lstchain.io.io import read_subarray_description
     from ctapipe.io import EventSource
 
-    source = EventSource(mc_gamma_testfile)
+    source = EventSource(mc_gamma_testfile, allowed_tels={1, 2, 3, 4})
     dl1_subarray = read_subarray_description(simulated_dl1_file)
     dl1_subarray.peek()
     dl1_subarray.info()
     assert len(dl1_subarray.tels) == len(source.subarray.tels)
     assert (dl1_subarray.to_table() == source.subarray.to_table()).all()
+
+
+def test_extract_simulation_nsb(mc_gamma_testfile):
+    from lstchain.io.io import extract_simulation_nsb
+    nsb = extract_simulation_nsb(mc_gamma_testfile)
+    assert np.isclose(nsb[0], 0.317, rtol=0.1)
+    assert np.isclose(nsb[1], 0.276, rtol=0.1)
