@@ -48,7 +48,7 @@ def main():
     args = parser.parse_args()
     
     output_dir = args.output_dir.absolute()
-    output_dir.mkdir(exist_ok=True)
+    output_dir.mkdir(exist_ok=True, parents=True)
     output_file = output_dir / r0_to_dl1_filename(args.input_file.name)
 
     r0_to_dl1.allowed_tels = {1, 2, 3, 4}
