@@ -16,28 +16,12 @@ test_data = Path(os.getenv('LSTCHAIN_TEST_DATA', 'test_data'))
 test_r0_path = test_data / 'real/R0/20200218/LST-1.1.Run02008.0000_first50.fits.fz'
 test_r0_path2 = test_data / 'real/R0/20200218/LST-1.1.Run02008.0100_first50.fits.fz'
 test_drs4_r0_path = test_data / 'real/R0/20200218/LST-1.1.Run02005.0000_first50.fits.fz'
-test_calib_path = test_data / 'real/calibration/20200218/v05/calibration.Run2006.0000.hdf5'
-test_drs4_pedestal_path = test_data / 'real/calibration/20200218/v05/drs4_pedestal.Run2005.0000.fits'
-test_time_calib_path = test_data / 'real/calibration/20200218/v05/time_calibration.Run2006.0000.hdf5'
+test_calib_path = test_data / 'real/monitoring/PixelCalibration/LevelA/calibration/20200218/v0.8.2.post2.dev48+gb1343281/calibration_filters_52.Run02006.0000.h5'
+test_drs4_pedestal_path = test_data / 'real/monitoring/PixelCalibration/LevelA/drs4_baseline/20200218/v0.8.2.post2.dev48+gb1343281/drs4_pedestal.Run02005.0000.h5'
+test_time_calib_path = test_data / 'real/monitoring/PixelCalibration/LevelA/drs4_time_sampling_from_FF/20191124/v0.8.2.post2.dev48+gb1343281/time_calibration.Run01625.0000.h5'
 test_drive_report = test_data / 'real/monitoring/DrivePositioning/drive_log_20200218.txt'
 
 
-def test_import_calib():
-    from lstchain import calib
-
-
-def test_import_reco():
-    from lstchain import reco
-
-
-def test_import_visualization():
-    from lstchain import visualization
-
-
-def test_import_lstio():
-    from lstchain import io
-
-
 @pytest.mark.run(order=1)
 def test_r0_to_dl1(tmp_path, mc_gamma_testfile):
     from lstchain.reco.r0_to_dl1 import r0_to_dl1
@@ -108,6 +92,7 @@ def test_get_source_dependent_parameters(simulated_dl1_file):
 
     dl1_params = pd.read_hdf(simulated_dl1_file, key=dl1_params_lstcam_key)
     src_dep_df = get_source_dependent_parameters(dl1_params, standard_config)
+    assert "alpha" in src_dep_df['on'].columns
 
 
 @pytest.mark.run(order=2)
@@ -115,7 +100,7 @@ def test_build_models(simulated_dl1_file, rf_models):
     from lstchain.reco.dl1_to_dl2 import build_models
     infile = simulated_dl1_file
 
-    reg_energy, reg_disp, cls_gh = build_models(
+    reg_energy, reg_disp_norm, cls_disp_sign, cls_gh = build_models(
         infile,
         infile,
         custom_config=standard_config,
@@ -125,8 +110,9 @@ def test_build_models(simulated_dl1_file, rf_models):
     import joblib
 
     joblib.dump(reg_energy, rf_models["energy"])
-    joblib.dump(reg_disp, rf_models["disp"])
     joblib.dump(cls_gh, rf_models["gh_sep"])
+    joblib.dump(reg_disp_norm, rf_models["disp_norm"])
+    joblib.dump(cls_disp_sign, rf_models["disp_sign"])
 
 
 @pytest.mark.run(order=3)
@@ -138,14 +124,19 @@ def test_apply_models(simulated_dl1_file, simulated_dl2_file, rf_models):
     dl1 = filter_events(
         dl1,
         filters=standard_config["events_filters"],
-        finite_params=standard_config['regression_features'] + standard_config['classification_features']
+        finite_params=standard_config['energy_regression_features']
+        + standard_config['disp_regression_features']
+        + standard_config['particle_classification_features']
+        + standard_config['disp_classification_features']
     )
 
     reg_energy = joblib.load(rf_models["energy"])
-    reg_disp = joblib.load(rf_models["disp"])
     reg_cls_gh = joblib.load(rf_models["gh_sep"])
+    reg_disp_norm = joblib.load(rf_models["disp_norm"])
+    cls_disp_sign = joblib.load(rf_models["disp_sign"])
 
-    dl2 = apply_models(dl1, reg_cls_gh, reg_energy, reg_disp, custom_config=standard_config)
+    dl2 = apply_models(dl1, reg_cls_gh, reg_energy, reg_disp_norm = reg_disp_norm, 
+                       cls_disp_sign = cls_disp_sign, custom_config=standard_config)
     dl2.to_hdf(simulated_dl2_file, key=dl2_params_lstcam_key)
 
 
@@ -168,7 +159,9 @@ def test_disp_vector():
     disp_angle = np.pi/3 * np.ones(3)
     disp_norm = np.ones(3)
     disp_sign = np.ones(3)
-    disp_dx, disp_dy = disp_vector(disp_norm, disp_angle, disp_sign)
+    disp_vec = disp_vector(disp_norm, disp_angle, disp_sign)
+    disp_dx = disp_vec[:, 0]
+    disp_dy = disp_vec[:, 1]
     np.testing.assert_array_equal([dx, dy], [disp_dx, disp_dy])
 
 
@@ -185,7 +178,7 @@ def test_disp_to_pos():
 
 def test_change_frame_camera_sky():
     from lstchain.reco.utils import sky_to_camera, camera_to_altaz
-    import astropy.units as u
+
     x = np.random.rand(1) * u.m
     y = np.random.rand(1) * u.m
     focal_length = 5 * u.m
